package de.ozgcloud.eingang.semantik.enginebased.afm;

import static java.util.Objects.*;
import static org.apache.commons.lang3.StringUtils.*;

import java.util.Collections;
import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.errorhandling.TechnicalException;
import de.ozgcloud.eingang.common.formdata.Antragsteller;
import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.semantik.common.ServiceKontoFactory;

@Component
public class AfmAntragstellerHeaderMapper {

	static final String KEY_VORNAME = "u:saml_givenname";
	static final String KEY_NACHNAME = "u:saml_surname";
	static final String KEY_GEBURTSORT = "u:saml_placeofbirth";
	public static final String KEY_GEBURTSNAME = "u:saml_birthname";
	static final String KEY_EMAIL = "u:saml_mail";
	static final String KEY_TELEFON = "u:saml_telephonenumber";
	static final String KEY_STRASSE = "u:saml_postaladdress";
	static final String KEY_PLZ = "u:saml_postalcode";
	static final String KEY_ORT = "u:saml_localityname";

	public FormData parseAntragstellerData(FormData formData) {
		return formData.toBuilder().antragsteller(buildAntragsteller(getHeaders(formData))).build();
	}

	Antragsteller buildAntragsteller(Map<String, Object> headers) {
		return Antragsteller.builder()
				.postfachId(MapUtils.getString(headers, ServiceKontoFactory.KEY_BAYERN_ID_POSTFACH_ID))
				.vorname(MapUtils.getString(headers, KEY_VORNAME))
				.nachname(MapUtils.getString(headers, KEY_NACHNAME))
				.geburtsname(MapUtils.getString(headers, KEY_GEBURTSNAME))
				.geburtsort(MapUtils.getString(headers, KEY_GEBURTSORT))
				.email(MapUtils.getString(headers, KEY_EMAIL))
				.telefon(MapUtils.getString(headers, KEY_TELEFON))
				.strasse(MapUtils.getString(headers, KEY_STRASSE))
				.plz(MapUtils.getString(headers, KEY_PLZ))
				.ort(MapUtils.getString(headers, KEY_ORT))
				.build();
	}

	public boolean isResponsible(FormData formData) {
		var headers = getHeaders(formData);
		return headers.containsKey(ServiceKontoFactory.KEY_BAYERN_ID_POSTFACH_ID)
				&& isPostfachIdNotBlank(headers.get(ServiceKontoFactory.KEY_BAYERN_ID_POSTFACH_ID));
	}

	@SuppressWarnings("unchecked")
	Map<String, Object> getHeaders(FormData formData) {
		return (Map<String, Object>) formData.getFormData().getOrDefault(AfmHeaderMapper.HEADER_FIELD, Collections.emptyMap());
	}

	boolean isPostfachIdNotBlank(Object postfachId) {
		if (isNull(postfachId)) {
			return false;
		}
		if (postfachId instanceof String id) {
			return isNotBlank(id);
		}
		throw new TechnicalException("Unexpected type of postfach id: " + postfachId.getClass().getName());
	}
}
